@@ -10,8 +10,10 @@ import yaml
 
 class Home():
     def __init__(self):
+        self.version = '0.1.17dev'
+
         print(
-            '\nWelcome to SIGACTor 0.1.16dev, currently available '
+            '\nWelcome to SIGACTor ' + self.version + ', currently available '
             'for the Syria team and reading posts from the '
             "Syrian Observatory for Human Rights' Facebook Page."
         )
@@ -28,6 +30,12 @@ class Home():
             'Air',
             'Targeted',
             'Tactical',
+            'Pro-regime KIA',
+            'Pro-regime WIA',
+            'Anti-regime KIA',
+            'Anti-regime WIA',
+            'Total KIA',
+            'Total WIA',
             'Outcome',
             'Full Text',
             'URL',
@@ -36,6 +44,7 @@ class Home():
             'Date Begin',
             'Date End',
             'Posted Date',
+            'Author',
         ]
 
         print('\nPreparing CSV...')
@@ -91,7 +100,9 @@ class Home():
             )
 
             try:
-                self.start_date = datetime.strptime(self.entered_date, '%Y-%m-%d-%H%M%z')
+                self.start_date = datetime.strptime(
+                    self.entered_date, '%Y-%m-%d-%H%M%z'
+                )
                 break
             except ValueError:
                 print('Invalid date. ')
