@@ -1,3 +1,6 @@
+from getpass import getuser
+
+
 class Property():
     def __init__(self, home, post, activity, name):
         self.home = home
@@ -12,37 +15,21 @@ class Property():
             self.value = ''
 
         if self.name == 'Location':
-            self.elements = [
-                'mosque',
-                'prison',
-                'airport',
-                'civilian airport',
-                'military airport',
-                'road',
-                'street',
-                'highway',
-                'area',
-                'neighborhood',
-                'neighbourhood',
-                'village',
-                'town',
-                'city',
-                'province',
-            ]
-
             self.units = {}
 
-            for number in range(0, len(self.elements)):
+            for number in range(0, len(post.elements)):
+                term = post.elements[number][0]
                 if number <= 7:
-                    self.units[self.elements[number]] = (
+                    self.units[term] = (
                         self.activity.content.locate(
-                            self.elements[number], tag=True
+                            term, tag=True
                         )
                     )
                 else:
-                    self.units[self.elements[number]] = (
-                        self.activity.content.locate(self.elements[number])
+                    self.units[term] = (
+                        self.activity.content.locate(term)
                     )
+                    self.value = self.units[term]
 
             if self.post.province:
                 self.units['province'] = self.post.province
@@ -51,29 +38,32 @@ class Property():
             if self.units['province'].lower() == 'damascus':
                 self.units['province'] = 'Dimashq'
 
-            if not self.units['town']:
+            if not self.units['city']:
                 if self.units['province'] in ['Aleppo', 'Hama', 'Homs']:
-                    self.town = self.post.province
-                    self.y += 'Town determined by province. '
-                if self.units['province'] == 'Raqqah':
-                    self.units['town'] = 'al-Raqqah'
-                    self.y += 'Town determined by province. '
+                    self.units['city'] = self.post.province
+                    self.y += 'City determined by province. '
+                if self.units['city'] == 'Raqqah':
+                    self.units['city'] = 'al-Raqqah'
+                    self.y += 'City determined by province. '
                 if self.units['province'] == 'Dimashq':
-                    self.units['town'] = 'Damascus'
-                    self.y += 'Town determined by province. '
+                    self.units['city'] = 'Damascus'
+                    self.y += 'City determined by province. '
 
             self.units['province'] = 'Rif ' + self.units['province']
 
-            for element in self.elements:
-                if self.units[element].lower() == 'the':
-                    if len(self.post.activities):
-                        self.units[element] = (
+            for element in post.elements:
+                term = element[0]
+                if self.units[term].lower() == 'the':
+                    if self.home.activities:
+                        self.units[term] = (
                             self.post.activities[self.activity.number - 1]
-                            .properties[1].units[element]
+                            .properties[1].units[term]
                         )
+                    else:
+                        self.units[term] = ''
 
-                if self.units[element]:
-                    self.value += self.units[element] + ', '
+                if self.units[term]:
+                    self.value += self.units[term] + ', '
 
             if self.value:
                 if self.value[-2:] == ', ':
@@ -148,13 +138,18 @@ class Property():
         if self.name == 'Blast':
             if self.activity.content.contains('bomb ', 'IED', 'bomber'):
                 self.value = 'IED'
-            if self.activity.content.contains('car bomb ', 'VBIED'):
+            if self.activity.content.contains(
+                'car bomb ', 'VBIED', 'car-bomb'
+            ):
                 self.value = 'VBIED'
             if self.activity.content.contains('suicide'):
                 self.value = 'SVEST'
 
             self.value = self.check(self.value)
 
+            if self.value:
+                self.activity.properties['Orientation'] = 'Anti-Regime'
+
         if self.name == 'Targeted':
             if self.activity.content.contains('execut'):
                 self.value = 'Execution'
@@ -172,6 +167,24 @@ class Property():
 
             self.value = self.check(self.value)
 
+        if self.name == 'Pro-regime KIA':
+            self.value = self.number_check(self.value)
+
+        if self.name == 'Pro-regime WIA':
+            self.value = self.number_check(self.value)
+
+        if self.name == 'Anti-regime KIA':
+            self.value = self.number_check(self.value)
+
+        if self.name == 'Anti-regime WIA':
+            self.value = self.number_check(self.value)
+
+        if self.name == 'Total KIA':
+            self.value = self.number_check(self.value)
+
+        if self.name == 'Total WIA':
+            self.value = self.number_check(self.value)
+
         if self.name == 'Outcome':
             if self.activity.properties['Blast'].value:
                 self.value = 'Effective'
@@ -204,8 +217,13 @@ class Property():
         if self.name == 'Posted Date':
             self.value = self.post.time
 
-    def check(self, value):
+        if self.name == 'Author':
+            self.value = (
+                getuser() + ' via SIGACTor ' + self.home.version + ' at ' +
+                self.post.now.strftime('%Y-%m-%d-%H%M')
+            )
 
+    def check(self, value):
         while True:
             answer = input(
                 '\nContent:\n' + self.activity.content.text + '\n' +
@@ -226,3 +244,16 @@ class Property():
                 return ''
             else:
                 return answer
+
+    def number_check(self, value):
+        while True:
+            answer = self.check(value)
+            if answer:
+                try:
+                    self.value_number = int(answer)
+                    return answer
+                except ValueError:
+                    print('\nInvalid answer. Please enter a number. ')
+                    continue
+            else:
+                return answer
